# HCiw
Additional utilities for using the Ciw Python package in healthcare.

```bash
.
├── dist
│   ├── HCiw-0.0.14-py3-none-any.whl
│   └── HCiw-0.0.14.tar.gz
├── LICENSE
├── pyproject.toml
├── README.md
├── requirements.txt
├── src
│   ├── hciw
│   │   ├── distributions.py
│   │   ├── __init__.py
│   │   ├── model_diagrams.py
│   │   ├── nodes.py
│   │   ├── results.py
│   │   ├── ruds.py
│   │   ├── server_schedules.py
│   │   ├── service_disciplines.py
│   │   └── waitlist.py
│   └── HCiw.egg-info
│       ├── dependency_links.txt
│       ├── PKG-INFO
│       ├── SOURCES.txt
│       └── top_level.txt
└── tests
    ├── service_disciplines.py
    └── test_waitlist.py

5 directories, 21 files
```
